pub struct EngineEffects<T> {
pub by_rank: Vec<RankEffects<T>>,
}Expand description
Effects produced by zero or more ranks of a logical engine.
Fields
by_rank: Vec<RankEffects<T>>Effects in stable DP-rank order.
Implementations
Sourceimpl<T> EngineEffects<T>
impl<T> EngineEffects<T>
Sourcepub fn into_by_rank(self) -> Vec<RankEffects<T>>
pub fn into_by_rank(self) -> Vec<RankEffects<T>>
Consume the wrapper and return effects in stable DP-rank order.