#[non_exhaustive]pub struct CacheTierAttribution {
pub g1_reused_input_tokens: usize,
pub host_reused_input_tokens: usize,
}Expand description
First-admission provenance for prompt tokens reused across cache tiers.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.g1_reused_input_tokens: usizeReused prompt tokens already resident in device KV before any H2D.
host_reused_input_tokens: usizeAdditional reused prompt tokens restored from the native host tier.