pub enum ForwardPassPerfSource {
Aic,
FallbackRegression,
AicWithCorrection,
}Expand description
Prediction backend currently used by ForwardPassPerfModel.
Variants
Aic
Strict native AIC estimator with no correction workload kind ready yet.
FallbackRegression
Workload-specific regression fallback, used without native AIC support.
AicWithCorrection
Native AIC estimator with at least one learned correction workload kind.