pub enum ReplayTelemetrySampleKind {
Baseline,
Periodic,
Final,
}Expand description
Why a replay telemetry sample was emitted.
Variants
Baseline
Gauge-only state after the initial replay timestamp has settled. Interval counters are not consumed by this sample.
Periodic
A complete configured sampling interval.
Final
The non-empty tail after the last periodic sample, including a zero-duration tail with observations recorded at the final timestamp.