pub struct KvIngestEventEncoder<'a> { /* private fields */ }Expand description
Neutral encoder used by observation adapters to contribute KV events to canonical replay evidence without exposing Router types to Replay.
Implementations
Sourceimpl KvIngestEventEncoder<'_>
impl KvIngestEventEncoder<'_>
pub fn begin_event( &mut self, worker_id: u64, dp_rank: u32, storage_tier_tag: u8, storage_tier_name: &'static str, event_id: u64, )
pub fn begin_kind(&mut self, tag: u8, name: &'static str)
pub fn add_blocks(&mut self, count: usize, context: &str) -> Result<()>
pub fn put_len(&mut self, value: usize, context: &str) -> Result<()>
pub fn put_u8(&mut self, value: u8)
pub fn put_u64(&mut self, value: u64)
pub fn put_optional_u32(&mut self, value: Option<u32>)
pub fn put_optional_u64(&mut self, value: Option<u64>)