pub struct Metrics {
pub dp_rank: u32,
pub active_blocks: u64,
pub total_blocks: u64,
pub cache_usage: f64,
pub running_requests: u64,
pub waiting_requests: u64,
pub preemptions_total: u64,
pub sglang_cache_hit_tokens: u64,
pub sglang_cache_total_tokens: u64,
}Expand description
Rank-local scheduler and G1 metrics.
Fields
dp_rank: u32active_blocks: u64total_blocks: u64cache_usage: f64running_requests: u64waiting_requests: u64preemptions_total: u64sglang_cache_hit_tokens: u64SGLang radix-cache tokens reused by the most recently completed pass.
Backends without an equivalent pass-local metric report zero.
sglang_cache_total_tokens: u64Total SGLang prefill tokens considered by the most recently completed pass. Backends without an equivalent pass-local metric report zero.